@@ -81,3 +81,14 @@ def test_no_dot():
 def test_no_dot_at_all():
     q = Line().render_pyquery()
     assert q(".text-overlay text").text() == 'No data'
+
+
+def test_not_equal_x_labels():
+    line = Line()
+    line.add('test1', range(100))
+    line.x_labels = map(str, range(11))
+    q = line.render_pyquery()
+    assert len(q(".dots")) == 100
+    assert len(q(".axis.x")) == 1
+    assert q(".axis.x text").map(texts) == ['0', '1', '2', '3', '4', '5', '6',
+                                            '7', '8', '9', '10']
